@@ -14,7 +14,7 @@ testDirectSqlite :: TestEnv -> Test
 testDirectSqlite TestEnv{..} = TestCase $ do
   let dsConn = connectionHandle conn
   bracket (DS.prepare dsConn "SELECT 1+1") DS.finalize testDirect
-  [Only (res :: Int)] <- query_ (Connection dsConn) "SELECT 1+2"
+  [Only (res :: Int)] <- query_ conn "SELECT 1+2"
   assertEqual "1+2" 3 res
   where
     testDirect stmt = do
