@@ -1,20 +1,22 @@
-
 import Common
 import Control.Exception (bracket)
 import Control.Monad     (when)
 import System.Exit       (exitFailure)
 import System.IO
 
-import Simple
-import ParamConv
-import Errors
-import Utf8Strings
-import UserInstances
-import TestImports()
-import Fold
-import Statement
 import Debug
 import DirectSqlite
+import Errors
+import Fold
+import ParamConv
+import QQ
+import Simple
+import Function
+import Statement
+import TestImports()
+import TestImports
+import UserInstances
+import Utf8Strings
 
 tests :: [TestEnv -> Test]
 tests =
@@ -24,23 +26,48 @@ tests =
     , TestLabel "Simple"    . testSimpleTime
     , TestLabel "Simple"    . testSimpleTimeFract
     , TestLabel "Simple"    . testSimpleInsertId
+    , TestLabel "Simple"    . testSimpleMultiInsert
+    , TestLabel "Simple"    . testSimpleUTCTime
+    , TestLabel "Simple"    . testSimpleUTCTimeTZ
+    , TestLabel "Simple"    . testSimpleUTCTimeParams
+    , TestLabel "Simple"    . testSimpleQueryCov
+    , TestLabel "Simple"    . testSimpleStrings
+    , TestLabel "Simple"    . testSimpleChanges
+    , TestLabel "ParamConv" . testParamConvNull
     , TestLabel "ParamConv" . testParamConvInt
+    , TestLabel "ParamConv" . testParamConvIntWidths
+    , TestLabel "ParamConv" . testParamConvIntWidthsFromField
     , TestLabel "ParamConv" . testParamConvFloat
     , TestLabel "ParamConv" . testParamConvDateTime
     , TestLabel "ParamConv" . testParamConvBools
+    , TestLabel "ParamConv" . testParamConvToRow
+    , TestLabel "ParamConv" . testParamConvFromRow
+    , TestLabel "ParamConv" . testParamConvComposite
+    , TestLabel "ParamConv" . testParamNamed
     , TestLabel "Errors"    . testErrorsColumns
     , TestLabel "Errors"    . testErrorsInvalidParams
+    , TestLabel "Errors"    . testErrorsInvalidNamedParams
     , TestLabel "Errors"    . testErrorsWithStatement
     , TestLabel "Errors"    . testErrorsColumnName
+    , TestLabel "Errors"    . testErrorsTransaction
+    , TestLabel "Errors"    . testErrorsImmediateTransaction
+    , TestLabel "Errors"    . testErrorsExclusiveTransaction
+    , TestLabel "Errors"    . testErrorsSavepoint
     , TestLabel "Utf8"      . testUtf8Simplest
     , TestLabel "Utf8"      . testBlobs
     , TestLabel "Instances" . testUserFromField
+    , TestLabel "Instances" . testSQLDataFromField
     , TestLabel "Fold"      . testFolds
     , TestLabel "Statement" . testBind
     , TestLabel "Statement" . testDoubleBind
     , TestLabel "Statement" . testPreparedStatements
+    , TestLabel "Statement" . testPreparedStatementsColumnCount
     , TestLabel "Debug"     . testDebugTracing
+    , TestLabel "Functions" . testExternalAddition
     , TestLabel "Direct"    . testDirectSqlite
+    , TestLabel "Imports"   . testImports
+    , TestLabel "QQ"        . testSimpleQQ
+    , TestLabel "QQ"        . testMultiLinedQQ
     ]
 
 -- | Action for connecting to the database that will be used for testing.
@@ -52,11 +79,7 @@ testConnect = open ":memory:"
 
 withTestEnv :: (TestEnv -> IO a) -> IO a
 withTestEnv cb =
-    withConn $ \conn ->
-        cb TestEnv
-            { conn     = conn
-            , withConn = withConn
-            }
+  withConn $ \conn -> cb TestEnv { conn = conn }
   where
     withConn = bracket testConnect close
 
